@@ -31,7 +31,7 @@ LONG_IDX = IAMC_IDX + ["year"]
 REQUIRED_COLS = ["region", "variable", "unit"]
 
 # illegal terms for data/meta column names to prevent attribute conflicts
-ILLEGAL_COLS = ["data", "meta"]
+ILLEGAL_COLS = ["data", "meta", "level"]
 
 # dictionary to translate column count to Excel column names
 NUMERIC_TO_STR = dict(
@@ -136,19 +136,15 @@ def write_sheet(writer, name, df, index=False):
 
 def read_pandas(path, sheet_name=["data*", "Data*"], *args, **kwargs):
     """Read a file and return a pandas.DataFrame"""
+
     if isinstance(path, Path) and path.suffix == ".csv":
         return pd.read_csv(path, *args, **kwargs)
-    else:
-        if isinstance(path, pd.ExcelFile):
-            xl = path
-        else:
-            xl = pd.ExcelFile(
-                path, engine="xlrd" if path.suffix == ".xls" else "openpyxl"
-            )
 
-        sheet_names = pd.Series(xl.sheet_names)
+    else:
+        xl = path if isinstance(path, pd.ExcelFile) else pd.ExcelFile(path)
 
         # reading multiple sheets
+        sheet_names = pd.Series(xl.sheet_names)
         if len(sheet_names) > 1:
             sheets = kwargs.pop("sheet_name", sheet_name)
             # apply pattern-matching for sheet names (use * as wildcard)
@@ -432,6 +428,11 @@ def find_depth(data, s="", level=None):
         whether depth satisfies the condition (equality if level is int,
         >= if ``.+``,  <= if ``.-``)
     """
+    if islistable(level):
+        raise ValueError(
+            "Level is only run with ints or strings, not lists. Use strings with "
+            "integers and + or - to filter by ranges."
+        )
     if isstr(data):
         return _find_depth([data], s, level)[0]
 
