@@ -13,7 +13,7 @@ def test_debiasing_count(test_pd_df, axis, exp):
     # modify the default test data to have three distinct scenarios
     test_pd_df.loc[1, "model"] = "model_b"
     df = IamDataFrame(test_pd_df)
-    df.compute_bias(method="count", name="bias", axis=axis)
+    df.compute.bias(method="count", name="bias", axis=axis)
 
     assert_array_equal(df["bias"].values, exp)
 
@@ -22,4 +22,4 @@ def test_debiasing_unknown_method(test_df_year):
     """Check computing bias weights counting the number of scenarios by scenario name"""
     msg = "Unknown method foo for computing bias weights!"
     with pytest.raises(ValueError, match=msg):
-        test_df_year.compute_bias(method="foo", name="bias", axis="scenario")
+        test_df_year.compute.bias(method="foo", name="bias", axis="scenario")
